@@ -3,9 +3,9 @@
 # An object-oriented Perl implementation of Sender Policy Framework.
 # <http://search.cpan.org/dist/Mail-SPF>
 #
-# (C) 2005-2009 Julian Mehnle <julian@mehnle.net>
+# (C) 2005-2012 Julian Mehnle <julian@mehnle.net>
 #     2005      Shevek <cpan@anarres.org>
-# $Id: SPF.pm 53 2009-10-31 21:40:08Z Julian Mehnle $
+# $Id: SPF.pm 63 2013-07-22 03:52:21Z julian $
 #
 ##############################################################################
 
@@ -17,11 +17,11 @@ Mail::SPF - An object-oriented implementation of Sender Policy Framework
 
 =head1 VERSION
 
-2.007
+2.009
 
 =cut
 
-use version; our $VERSION = qv('2.007');
+our $VERSION = '3.20240205'; # VERSION
 
 use warnings;
 use strict;
@@ -35,9 +35,9 @@ use constant FALSE  => not TRUE;
 =head1 SYNOPSIS
 
     use Mail::SPF;
-    
+
     my $spf_server  = Mail::SPF::Server->new();
-    
+
     my $request     = Mail::SPF::Request->new(
         versions        => [1, 2],              # optional
         scope           => 'mfrom',             # or 'helo', 'pra'
@@ -46,9 +46,9 @@ use constant FALSE  => not TRUE;
         helo_identity   => 'mta.example.com'    # optional,
                                                 #   for %{h} macro expansion
     );
-    
+
     my $result      = $spf_server->process($request);
-    
+
     print("$result\n");
     my $result_code     = $result->code;        # 'pass', 'fail', etc.
     my $local_exp       = $result->local_explanation;
@@ -82,7 +82,7 @@ L<http://www.openspf.org>
 
 =item The SPFv1 specification (RFC 4408)
 
-L<http://www.openspf.org/Specifications>, L<http://www.ietf.org/rfc/rfc4408.txt>
+L<http://www.openspf.org/Specifications>, L<http://tools.ietf.org/html/rfc4408>
 
 =back
 
