@@ -2,9 +2,9 @@
 # Mail::SPF::Mech::MX
 # SPF record "mx" mechanism class.
 #
-# (C) 2005-2008 Julian Mehnle <julian@mehnle.net>
+# (C) 2005-2012 Julian Mehnle <julian@mehnle.net>
 #     2005      Shevek <cpan@anarres.org>
-# $Id: MX.pm 50 2008-08-17 21:28:15Z Julian Mehnle $
+# $Id: MX.pm 57 2012-01-30 08:15:31Z julian $
 #
 ##############################################################################
 
@@ -169,20 +169,20 @@ when matching address records against the request's IP address.  See RFC 4408,
 
 sub match {
     my ($self, $server, $request) = @_;
-    
+
     $server->count_dns_interactive_term($request);
-    
+
     my $target_domain = $self->domain($server, $request);
     my $mx_packet     = $server->dns_lookup($target_domain, 'MX');
     my @mx_rrs        = $mx_packet->answer
         or $server->count_void_dns_lookup($request);
-    
+
     # Respect the MX mechanism lookups limit (RFC 4408, 5.4/3/4):
     @mx_rrs = splice(@mx_rrs, 0, $server->max_name_lookups_per_mx_mech)
         if defined($server->max_name_lookups_per_mx_mech);
-    
+
     # TODO Use A records from packet's "additional" section?  Probably not.
-    
+
     # Check MX records:
     foreach my $rr (@mx_rrs) {
         if ($rr->type eq 'MX') {
@@ -194,7 +194,7 @@ sub match {
             # TODO Generate debug info or ignore silently.
         }
     }
-    
+
     return FALSE;
 }
 
@@ -204,7 +204,7 @@ sub match {
 
 L<Mail::SPF>, L<Mail::SPF::Record>, L<Mail::SPF::Term>, L<Mail::SPF::Mech>
 
-L<http://www.ietf.org/rfc/rfc4408.txt>
+L<http://tools.ietf.org/html/rfc4408>
 
 For availability, support, and license information, see the README file
 included with Mail::SPF.
