@@ -2,9 +2,9 @@
 # Mail::SPF::Server
 # Server class for processing SPF requests.
 #
-# (C) 2005-2008 Julian Mehnle <julian@mehnle.net>
+# (C) 2005-2012 Julian Mehnle <julian@mehnle.net>
 #     2005      Shevek <cpan@anarres.org>
-# $Id: Server.pm 50 2008-08-17 21:28:15Z Julian Mehnle $
+# $Id: Server.pm 61 2013-07-22 03:45:15Z julian $
 #
 ##############################################################################
 
@@ -39,13 +39,13 @@ use constant record_classes_by_version => {
 use constant result_base_class => 'Mail::SPF::Result';
 
 use constant query_rr_type_all                      => 0;
-use constant query_rr_type_spf                      => 1;
-use constant query_rr_type_txt                      => 2;
+use constant query_rr_type_txt                      => 1;
+use constant query_rr_type_spf                      => 2;
 
 use constant default_default_authority_explanation  =>
     'Please see http://www.openspf.org/Why?s=%{_scope};id=%{S};ip=%{C};r=%{R}';
 
-sub default_query_rr_types { shift->query_rr_type_all };
+sub default_query_rr_types { shift->query_rr_type_txt };
 
 use constant default_max_dns_interactive_terms      => 10;  # RFC 4408, 10.1/6
 use constant default_max_name_lookups_per_term      => 10;  # RFC 4408, 10.1/7
@@ -60,13 +60,13 @@ use constant default_max_void_dns_lookups           => 2;
 =head1 SYNOPSIS
 
     use Mail::SPF;
-    
+
     my $spf_server  = Mail::SPF::Server->new(
         # Optional custom default for authority explanation:
         default_authority_explanation =>
             'See http://www.%{d}/why/id=%{S};ip=%{I};r=%{R}'
     );
-    
+
     my $result      = $spf_server->process($request);
 
 =cut
@@ -130,26 +130,27 @@ following values are supported:
 
 =over
 
-=item B<< Mail::SPF::Server->query_rr_type_all >> (default)
+=item B<< Mail::SPF::Server->query_rr_type_all >>
 
-Both C<SPF> and C<TXT> type RRs.
+Both C<TXT> and C<SPF> type RRs.
+
+=item B<< Mail::SPF::Server->query_rr_type_txt >> (default)
+
+C<TXT> type RRs only.
 
 =item B<< Mail::SPF::Server->query_rr_type_spf >>
 
 C<SPF> type RRs only.
 
-=item B<< Mail::SPF::Server->query_rr_type_txt >>
-
-C<TXT> type RRs only.
-
 =back
 
-Some (few) name servers suffer from serious brain damage with regard to the
-handling of queries for RR types that are unknown to them, such as the C<SPF>
-RR type, so some (few) B<Mail::SPF> users have expressed the desire for a way
-to disable the retrieval of C<SPF> type RRs.  It is, however, a better idea to
-pressure the manufacturers of such broken name servers into fixing their
-products.
+For years B<Mail::SPF> has defaulted to looking up both C<SPF> and C<TXT> type
+RRs as recommended by RFC 4408.  Experience has shown, however, that a
+significant portion of name servers suffer from serious brain damage with
+regard to the handling of queries for RR types that are unknown to them, such
+as the C<SPF> RR type.  Consequently B<Mail::SPF> now defaults to looking up
+only C<TXT> type RRs.  This may be overridden by setting the B<query_rr_types>
+option.
 
 See RFC 4408, 3.1.1, for a discussion of the topic, as well as the description
 of the L</select_record> method.
@@ -209,7 +210,7 @@ would normally be returned.
 sub new {
     my ($self, %options) = @_;
     $self = $self->SUPER::new(%options);
-    
+
     $self->{default_authority_explanation} = $self->default_default_authority_explanation
         if not defined($self->{default_authority_explanation});
     $self->{default_authority_explanation} = Mail::SPF::MacroString->new(
@@ -218,14 +219,14 @@ sub new {
         is_explanation  => TRUE
     )
         if not UNIVERSAL::isa($self->{default_authority_explanation}, 'Mail::SPF::MacroString');
-    
+
     $self->{hostname} ||= Mail::SPF::Util->hostname;
-    
+
     $self->{dns_resolver} ||= Net::DNS::Resolver->new();
-    
+
     $self->{query_rr_types} = $self->default_query_rr_types
         if not defined($self->{query_rr_types});
-    
+
     $self->{max_dns_interactive_terms}      = $self->default_max_dns_interactive_terms
                                        if not exists($self->{max_dns_interactive_terms});
     $self->{max_name_lookups_per_term}      = $self->default_max_name_lookups_per_term
@@ -234,10 +235,10 @@ sub new {
                                        if not exists($self->{max_name_lookups_per_mx_mech});
     $self->{max_name_lookups_per_ptr_mech}  = $self->default_max_name_lookups_per_ptr_mech
                                        if not exists($self->{max_name_lookups_per_ptr_mech});
-    
+
     $self->{max_void_dns_lookups}           = $self->default_max_void_dns_lookups
                                        if not exists($self->{max_void_dns_lookups});
-    
+
     return $self;
 }
 
@@ -313,11 +314,11 @@ details.
 
 sub process {
     my ($self, $request) = @_;
-    
+
     $request->state('authority_explanation', undef);
     $request->state('dns_interactive_terms_count', 0);
     $request->state('void_dns_lookups_count', 0);
-    
+
     my $result;
     try {
         my $record = $self->select_record($request);
@@ -344,7 +345,7 @@ sub process {
     };
     # Propagate other, unknown errors.
     # This should not happen, but if it does, it helps exposing the bug!
-    
+
     return $result;
 }
 
@@ -358,7 +359,8 @@ sender policy records and, if multiple records are available, selects the
 record of the highest acceptable record version that covers the requested
 scope.
 
-More precisely, the following algorithm is performed:
+More precisely, the following algorithm is performed (assuming that both C<TXT>
+and C<SPF> RR types are being queried):
 
 =over
 
@@ -401,20 +403,20 @@ also be thrown.
 
 sub select_record {
     my ($self, $request) = @_;
-    
+
     my $domain   = $request->authority_domain;
     my @versions = $request->versions;
     my $scope    = $request->scope;
-    
+
     # Employ identical behavior for 'v=spf1' and 'spf2.0' records, both of
     # which support SPF (code 99) and TXT type records (this may be different
     # in future revisions of SPF):
     # Query for SPF type records first, then fall back to TXT type records.
-    
+
     my @records;
     my $query_count = 0;
     my @dns_errors;
-    
+
     # Query for SPF-type RRs first:
     if (
         $self->query_rr_types == $self->query_rr_type_all or
@@ -437,7 +439,7 @@ sub select_record {
         #    # Apparrently some brain-dead DNS servers time out on SPF-type queries.
         #};
     }
-    
+
     # If no usable SPF-type RRs, try TXT-type RRs:
     if (
         not @records and
@@ -455,7 +457,7 @@ sub select_record {
         #   Implication:  Sender ID processing may make use of existing TXT-
         #   type records where a result of "None" would normally be returned
         #   under a strict interpretation of RFC 4406.
-        
+
         try {
             $query_count++;
             my $packet = $self->dns_lookup($domain, 'TXT');
@@ -469,24 +471,24 @@ sub select_record {
             push(@dns_errors, shift);
         };
     }
-    
+
     @dns_errors < $query_count
         or $dns_errors[0]->throw;
         # Unless at least one query succeeded, re-throw the first DNS error that occurred.
-    
+
     @records
         or throw Mail::SPF::ENoAcceptableRecord(
             "No applicable sender policy available");  # RFC 4408, 4.5/7
-    
+
     # Discard all records but the highest acceptable version:
     my $preferred_record_class = $records[0]->class;
     @records = grep($_->isa($preferred_record_class), @records);
-    
+
     @records == 1
         or throw Mail::SPF::ERedundantAcceptableRecords(
             "Redundant applicable '" . $preferred_record_class->version_tag . "' " .
             "sender policies found");  # RFC 4408, 4.5/6
-    
+
     return $records[0];
 }
 
@@ -502,18 +504,25 @@ do not cover the given scope.  Returns a list of acceptable records.
 
 sub get_acceptable_records_from_packet {
     my ($self, $packet, $rr_type, $versions, $scope, $domain) = @_;
-    
+
     my @versions = sort { $b <=> $a } @$versions;
         # Try higher record versions first.
         # (This may be too simplistic for future revisions of SPF.)
-    
+
     my @records;
+
     foreach my $rr ($packet->answer) {
         next if $rr->type ne $rr_type;  # Ignore RRs of unexpected type.
-        
-        my $text = join('', $rr->char_str_list);
+
+        # char_str_list method is 'historical', use as a fallback for Net::DNS prior to 0.69
+        # where txtdata is not available.
+        # join with no intervening spaces, RFC 6376
+        # must call txtdata() in a list context
+        my $text = $rr->can('txtdata')
+                 ? join('', $rr->txtdata)
+                 : join('', $rr->char_str_list);
         my $record;
-        
+
         # Try to parse RR as each of the requested record versions,
         # starting from the highest version:
         VERSION:
@@ -528,7 +537,7 @@ sub get_acceptable_records_from_packet {
                 # Propagate other errors (including syntax errors), though.
             last VERSION if defined($record);
         }
-        
+
         push(@records, $record)
             if  defined($record)
             and grep($scope eq $_, $record->scopes);  # record covers requested scope?
@@ -549,7 +558,7 @@ error (other than RCODE 3 AKA C<NXDOMAIN>) occurred.
 
 sub dns_lookup {
     my ($self, $domain, $rr_type) = @_;
-    
+
     if (UNIVERSAL::isa($domain, 'Mail::SPF::MacroString')) {
         $domain = $domain->expand;
         # Truncate overlong labels at 63 bytes (RFC 4408, 8.1/27):
@@ -558,11 +567,11 @@ sub dns_lookup {
         $domain =~ s/^[^.]+\.(.*)$/$1/
             while length($domain) > 253;
     }
-    
+
     $domain =~ s/^(.*?)\.?$/\L$1/;  # Normalize domain.
-    
+
     my $packet = $self->dns_resolver->send($domain, $rr_type);
-    
+
     # Throw DNS exception unless an answer packet with RCODE 0 or 3 (NXDOMAIN)
     # was received (thereby treating NXDOMAIN as an acceptable but empty answer packet):
     $self->dns_resolver->errorstring !~ /^(timeout|query timed out)$/
@@ -574,7 +583,7 @@ sub dns_lookup {
     $packet->header->rcode =~ /^(NOERROR|NXDOMAIN)$/
         or throw Mail::SPF::EDNSError(
             "'" . $packet->header->rcode . "' error on DNS '$rr_type' lookup of '$domain'");
-    
+
     return $packet;
 }
 
@@ -679,15 +688,15 @@ __PACKAGE__->make_accessor($_, TRUE)
     foreach qw(
         default_authority_explanation
         hostname
-        
+
         dns_resolver
         query_rr_types
-        
+
         max_dns_interactive_terms
         max_name_lookups_per_term
         max_name_lookups_per_mx_mech
         max_name_lookups_per_ptr_mech
-        
+
         max_void_dns_lookups
     );
 
@@ -697,7 +706,7 @@ __PACKAGE__->make_accessor($_, TRUE)
 
 L<Mail::SPF>, L<Mail::SPF::Request>, L<Mail::SPF::Result>
 
-L<http://www.ietf.org/rfc/rfc4408.txt>
+L<http://tools.ietf.org/html/rfc4408>
 
 For availability, support, and license information, see the README file
 included with Mail::SPF.
